==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXAnywhereAuth.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXAnywhereAuth;no warnings;($username=(""));($isDefaultUser=
(0x1d2f+ 1537-0x2330));sub checkToken{(my $request=shift (@_));Logger::debug (((
"\x63\x68\x65\x63\x6b\x43\x6c\x69\x65\x6e\x74\x52\x65\x71\x75\x65\x73\x74\x20\x5b"
.$request)."\x5d"));if (($request=~ /username=(.*)&token=(.*)/ )){(my $clientUsername
=main::urldecode ($1));(my $clientToken=main::urldecode ($2));if (
isSupportedToken ($clientToken,$clientUsername)){Logger::debug (
"\x63\x68\x65\x63\x6b\x43\x6c\x69\x65\x6e\x74\x52\x65\x71\x75\x65\x73\x74\x20\x54\x4f\x4b\x45\x4e\x20\x73\x75\x70\x70\x6f\x72\x74\x65\x64"
);($username=$clientUsername);return ((0x0b1d+ 1469-0x10d9));}}(my $name=
Server::getAnywhereName ());Logger::warning (((($name.
"\x20\x41\x75\x74\x68\x3a\x20\x52\x65\x63\x65\x69\x76\x65\x64\x20\x77\x72\x6f\x6e\x67\x20\x74\x6f\x6b\x65\x6e\x20\x27"
).$request)."\x27\x20\x2e"));return ((0x0c3b+ 6664-0x2643));}sub 
isSupportedToken{(my $clientToken=shift (@_));(my $clientUsername=shift (@_));(my $token
=libnxh::NXTransGetEnvironment ("\x4e\x58\x5f\x54\x4f\x4b\x45\x4e"));
Logger::debug (((((((
"\x43\x68\x65\x63\x6b\x69\x6e\x67\x20\x63\x6c\x69\x65\x6e\x74\x20\x74\x6f\x6b\x65\x6e\x20\x5b"
.$clientToken).
"\x5d\x20\x66\x6f\x72\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x20\x5b").
$clientUsername)."\x5d\x20\x77\x69\x74\x68\x20\x74\x6f\x6b\x65\x6e\x20\x5b").
$token)."\x5d"));if (($clientUsername eq (""))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x68\x65\x63\x6b\x20\x74\x6f\x6b\x65\x6e\x20\x66\x6f\x72\x20\x65\x6d\x70\x74\x79\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x2e"
);return ((0x03d0+ 4610-0x15d2));}if (($clientToken eq $token)){Logger::debug (
"\x69\x73\x53\x75\x70\x70\x6f\x72\x74\x65\x64\x54\x6f\x6b\x65\x6e\x20\x4f\x4b");
return ((0x0369+ 104-0x03d0));}Logger::debug (
"\x69\x73\x53\x75\x70\x70\x6f\x72\x74\x65\x64\x54\x6f\x6b\x65\x6e\x20\x46\x41\x49\x4c"
);return ((0x092d+ 3011-0x14f0));}sub getUsername{if (($username ne (""))){
return ($username);}else{Logger::error ((Server::getAnywhereName ().
"\x20\x75\x73\x65\x72\x20\x69\x73\x20\x6e\x6f\x74\x20\x73\x65\x74\x2e"));
Common::NXCore::assertExit ();}}sub setDefaultUser{($isDefaultUser=
(0x11b3+ 1831-0x18d9));}sub isDefaultUser{return ($isDefaultUser);}return (
(0x1ac5+ 1755-0x219f));

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXAnywhereAuth.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXAnywhereAuth;no warnings;($username=(""));($isDefaultUser=
(0x02fb+ 5707-0x1946));sub checkToken{(my $request=shift (@_));Logger::debug (((
"\x63\x68\x65\x63\x6b\x43\x6c\x69\x65\x6e\x74\x52\x65\x71\x75\x65\x73\x74\x20\x5b"
.$request)."\x5d"));if (($request=~ /username=(.*)&token=(.*)/ )){(my $clientUsername
=main::urldecode ($1));(my $clientToken=main::urldecode ($2));if (
isSupportedToken ($clientToken,$clientUsername)){Logger::debug (
"\x63\x68\x65\x63\x6b\x43\x6c\x69\x65\x6e\x74\x52\x65\x71\x75\x65\x73\x74\x20\x54\x4f\x4b\x45\x4e\x20\x73\x75\x70\x70\x6f\x72\x74\x65\x64"
);($username=$clientUsername);return ((0x00a8+ 8800-0x2307));}}(my $name=
Server::getAnywhereName ());Logger::warning (((($name.
"\x20\x41\x75\x74\x68\x3a\x20\x52\x65\x63\x65\x69\x76\x65\x64\x20\x77\x72\x6f\x6e\x67\x20\x74\x6f\x6b\x65\x6e\x20\x27"
).$request)."\x27\x20\x2e"));return ((0x2406+ 736-0x26e6));}sub isSupportedToken
{(my $clientToken=shift (@_));(my $clientUsername=shift (@_));(my $token=
libnxh::NXTransGetEnvironment ("\x4e\x58\x5f\x54\x4f\x4b\x45\x4e"));
Logger::debug (((((((
"\x43\x68\x65\x63\x6b\x69\x6e\x67\x20\x63\x6c\x69\x65\x6e\x74\x20\x74\x6f\x6b\x65\x6e\x20\x5b"
.$clientToken).
"\x5d\x20\x66\x6f\x72\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x20\x5b").
$clientUsername)."\x5d\x20\x77\x69\x74\x68\x20\x74\x6f\x6b\x65\x6e\x20\x5b").
$token)."\x5d"));if (($clientUsername eq (""))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x68\x65\x63\x6b\x20\x74\x6f\x6b\x65\x6e\x20\x66\x6f\x72\x20\x65\x6d\x70\x74\x79\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x2e"
);return ((0x0071+ 3649-0x0eb2));}if (($clientToken eq $token)){Logger::debug (
"\x69\x73\x53\x75\x70\x70\x6f\x72\x74\x65\x64\x54\x6f\x6b\x65\x6e\x20\x4f\x4b");
return ((0x07c1+ 1983-0x0f7f));}Logger::debug (
"\x69\x73\x53\x75\x70\x70\x6f\x72\x74\x65\x64\x54\x6f\x6b\x65\x6e\x20\x46\x41\x49\x4c"
);return ((0x0c2a+ 5170-0x205c));}sub getUsername{if (($username ne (""))){
return ($username);}else{Logger::error ((Server::getAnywhereName ().
"\x20\x75\x73\x65\x72\x20\x69\x73\x20\x6e\x6f\x74\x20\x73\x65\x74\x2e"));
Common::NXCore::assertExit ();}}sub setDefaultUser{($isDefaultUser=
(0x025d+ 450-0x041e));}sub isDefaultUser{return ($isDefaultUser);}return (
(0x122b+ 3858-0x213c));
